==> common-3.0.8-sources.jar: com/microsoft/identity/common/internal/controllers/CommandResult.java <==
//  Copyright (c) Microsoft Corporation.
//  All rights reserved.
//
//  This code is licensed under the MIT License.
//
//  Permission is hereby granted, free of charge, to any person obtaining a copy
//  of this software and associated documentation files(the "Software"), to deal
//  in the Software without restriction, including without limitation the rights
//  to use, copy, modify, merge, publish, distribute, sublicense, and / or sell
//  copies of the Software, and to permit persons to whom the Software is
//  furnished to do so, subject to the following conditions :
//
//  The above copyright notice and this permission notice shall be included in
//  all copies or substantial portions of the Software.
//
//  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
//  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
//  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
//  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
//  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
//  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
//  THE SOFTWARE.
package com.microsoft.identity.common.internal.controllers;

public class CommandResult {

    public enum ResultStatus { CANCEL, COMPLETED, ERROR };

    private ResultStatus mStatus;
    private Object mResult;

    public CommandResult(ResultStatus status, Object result){
        mStatus = status;
        mResult = result;
    }

    public ResultStatus getStatus(){
        return mStatus;
    }

    public Object getResult(){
        return mResult;
    }

}

==> common-3.4.4-sources.jar: com/microsoft/identity/common/internal/controllers/CommandResult.java <==
//  Copyright (c) Microsoft Corporation.
//  All rights reserved.
//
//  This code is licensed under the MIT License.
//
//  Permission is hereby granted, free of charge, to any person obtaining a copy
//  of this software and associated documentation files(the "Software"), to deal
//  in the Software without restriction, including without limitation the rights
//  to use, copy, modify, merge, publish, distribute, sublicense, and / or sell
//  copies of the Software, and to permit persons to whom the Software is
//  furnished to do so, subject to the following conditions :
//
//  The above copyright notice and this permission notice shall be included in
//  all copies or substantial portions of the Software.
//
//  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
//  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
//  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
//  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
//  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
//  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
//  THE SOFTWARE.
package com.microsoft.identity.common.internal.controllers;

import androidx.annotation.Nullable;

public class CommandResult {

    public String getCorrelationId() {
        return mCorrelationId;
    }

    public enum ResultStatus {
        CANCEL,
        COMPLETED,
        ERROR;

        public String getLogStatus() {
            if (ResultStatus.COMPLETED == this) {
                return "SUCCESS";
            } else if (ResultStatus.ERROR == this) {
                return "ERROR";
            } else {
                return "CANCEL";
            }
        }
    }

    private final ResultStatus mStatus;
    private final Object mResult;
    private final String mCorrelationId;

    public CommandResult(ResultStatus status, Object result) {
        this(status, result, null);
    }

    public CommandResult(ResultStatus status, Object result, @Nullable String correlationId) {
        mStatus = status;
        mResult = result;
        mCorrelationId = correlationId == null ? "UNSET" : correlationId;
    }

    public ResultStatus getStatus() {
        return mStatus;
    }

    public Object getResult() {
        return mResult;
    }

}
